spectra

- python: 3.7.3

- torch: 1.4.0
- torchaudio: 0.4.0

Usage

- MFCC
- Filterbank
- Log Filterbank

The difference between spectra(A) and python_speech_features(B):

- Precision bais: 1e-4
- Speed up: 0.1s/mfcc